@@ -4,7 +4,7 @@
 
 //! Legacy traditional Chinese encodings.
 
-use std::borrow::IntoCow;
+use std::convert::Into;
 use util::StrCharIndex;
 use index_tradchinese as index;
 use types::*;
@@ -56,7 +56,7 @@ impl RawEncoder for BigFive2003Encoder {
                 if ptr == 0xffff || ptr < (0xa1 - 0x81) * 157 {
                     // no HKSCS extension (XXX doesn't HKSCS include 0xFA40..0xFEFE?)
                     return (i, Some(CodecError {
-                        upto: j as isize, cause: "unrepresentable character".into_cow()
+                        upto: j as isize, cause: "unrepresentable character".into()
                     }));
                 }
                 let lead = ptr / 157 + 0x81;
@@ -125,7 +125,6 @@ transient:
 mod bigfive2003_tests {
     extern crate test;
     use super::BigFive2003Encoding;
-    use std::iter::range_inclusive;
     use testutils;
     use types::*;
 
@@ -172,7 +171,7 @@ mod bigfive2003_tests {
 
     #[test]
     fn test_decoder_invalid_lone_lead_immediate_test_finish() {
-        for i in range_inclusive(0x81u8, 0xfe) {
+        for i in 0x81..0xff {
             let mut d = BigFive2003Encoding.raw_decoder();
             assert_feed_ok!(d, [], [i], ""); // wait for a trail
             assert_finish_err!(d, "");
@@ -187,7 +186,8 @@ mod bigfive2003_tests {
 
     #[test]
     fn test_decoder_invalid_lone_lead_followed_by_space() {
-        for i in range_inclusive(0x80u8, 0xff) {
+        for i in 0x80..0x100 {
+            let i = i as u8;
             let mut d = BigFive2003Encoding.raw_decoder();
             assert_feed_err!(d, [], [i], [0x20], "");
             assert_finish_ok!(d, "");
@@ -198,7 +198,7 @@ mod bigfive2003_tests {
     fn test_decoder_invalid_lead_followed_by_invalid_trail() {
         // unlike most other cases, valid lead + invalid MSB-set trail are entirely consumed.
         // https://www.w3.org/Bugs/Public/show_bug.cgi?id=16771
-        for i in range_inclusive(0x81u8, 0xfe) {
+        for i in 0x81..0xff {
             let mut d = BigFive2003Encoding.raw_decoder();
             assert_feed_err!(d, [], [i, 0x80], [0x20], "");
             assert_feed_err!(d, [], [i, 0xff], [0x20], "");
